@@ -2,105 +2,11 @@ package Clustericious;
 
 use strict;
 use warnings;
-use 5.010;
-use File::Spec;
-use File::Glob qw( bsd_glob );
-use File::Path qw( mkpath );
 
 # ABSTRACT: A framework for RESTful processing systems.
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
-sub _testing
-{
-  state $test = 0;
-  my($class, $new) = @_;
-  $test = $new if defined $new;
-  $test;
-}
-
-sub _config_path
-{
-  grep { -d $_ }
-    map { File::Spec->catdir(@$_) } 
-    grep { defined $_->[0] }
-    (
-      [ $ENV{CLUSTERICIOUS_CONF_DIR} ],
-      (!_testing) ? (
-        [ bsd_glob('~'), 'etc' ],
-        [ bsd_glob('~/.config/Perl/Clustericious') ],
-        [ '', 'etc' ],
-      ) : (),
-    );
-}
-
-sub _slurp_pid ($)
-{
-  use autodie;
-  my($fn) = @_;
-  open my $fh, '<', $fn;
-  my $pid = <$fh>;
-  close $fh;
-  chomp $pid;
-  $pid;
-}
-
-sub _dist_dir
-{
-  state $dir;
-  $dir //= do {
-    require Path::Class::Dir;
-    require File::ShareDir::Dist;
-    Path::Class::Dir->new(
-      File::ShareDir::Dist::dist_share('Clustericious') or die "unable to find share directory",
-    );
-  };
-}
-
-sub _generate_port
-{
-  require IO::Socket::INET;
-  # this code is duplicated in Test::Clustericious::Command,
-  # don't want to move it just FYI
-  IO::Socket::INET->new(Listen => 5, LocalAddr => "127.0.0.1")->sockport
-}
-
-sub _my_dist_data
-{
-  my $dir = bsd_glob '~/.local/share/Perl/dist/Clustericious';
-  mkpath $dir, 0, 0700;
-  $dir;
-}
-
-sub _default_url
-{
-  my(undef, $app_name) = @_;
-  require Path::Class::File;
-  require JSON::MaybeXS;
-  require Mojo::URL;
-  my $file = Path::Class::File->new(_my_dist_data(), 'default_ports.json');
-
-  $app_name =~ s{::}{-};
-  
-  my $data = -f $file ? JSON::MaybeXS::decode_json(scalar $file->slurp) : {};
-  
-  $data->{$app_name} // do {
-    my $url = Mojo::URL->new('http://127.0.0.1');
-    $url->port(__PACKAGE__->_generate_port);
-    $url = $url->to_string;
-
-    $data->{$app_name} = $url;
-    $file->spew(JSON::MaybeXS::encode_json($data));
-
-    $url;
-  };
-}
-
-# Note sub _config_uncache also gets placed
-# in this package, but it is defined in
-# Clustericious::Config.
-
 1;
 
 __END__
@@ -115,7 +21,7 @@ Clustericious - A framework for RESTful processing systems.
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -123,6 +29,10 @@ Generate a new Clustericious application:
 
  % clustericious generate app MyApp
 
+Generate a new Clustericious application database schema:
+
+ % clustericious generate mbd_app MyApp --schema schema.sql
+
 Basic application layout:
 
  package MyApp;
@@ -132,8 +42,7 @@ Basic application layout:
  sub startup
  {
    my($self) = @_;
-   $self->SUPER::startup;
-   # app startup
+   # just like Mojolicious startup()
  }
  
  package MyApp::Routes;
@@ -191,7 +100,7 @@ Simplified route builder based on L<Mojolicious::Lite> (see L<Clustericious::Rou
 =item *
 
 Provides a set of default routes (e.g. /status, /version, /api) for consistent
-interaction with Clustericious services (see L<Clustericious::Plugin::CommonRoutes>).
+interaction with Clustericious services (see L<Clustericious::RouteBuilder::Common>).
 
 =item *
 
@@ -227,6 +136,45 @@ facilities for a variety of deployment options.
 
 =back
 
+=head1 TODO
+
+I am ramping up to a release candidate and a final release for 1.00.
+Specific things that need to be completed for this task include
+(but are not limited to):
+
+=over 4
+
+=item *
+
+documentation tutorial for a non database app
+
+=item *
+
+documentation tutorial for a L<Module::Build::Database> / L<Rose::Planter> app 
+(replacement for the existing README, which is broken)
+
+=item *
+
+use SQLite for above instead of Postgres
+
+=item *
+
+documentation tutorial for migrating SQLite app to Postgres
+
+=item *
+
+documentation tutorial for clients (L<Clustericious::Client>)
+
+=item *
+
+remove C<TEST_HARNESS> detection / dependency (see GH#8)
+
+=back
+
+=head1 NOTES
+
+This is a beta release.  The API is subject to change without notice.
+
 =head1 AUTHOR
 
 Original author: Brian Duggan
@@ -237,8 +185,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
