@@ -3,11 +3,17 @@ package Clustericious::Client;
 use strict;
 use warnings;
 use 5.010;
+
+# ABSTRACT: Construct command line and perl clients for RESTful services.
+our $VERSION = '1.01'; # VERSION
+
+
 use Mojo::Base qw/-base/;
+
 use Mojo::UserAgent;
 use Mojo::ByteStream qw/b/;
 use Mojo::Parameters;
-use Clustericious;
+use JSON::XS;
 use Clustericious::Config;
 use Clustericious::Client::Object;
 use Clustericious::Client::Meta;
@@ -15,44 +21,30 @@ use Clustericious::Client::Meta::Route;
 use MojoX::Log::Log4perl;
 use Log::Log4perl qw/:easy/;
 use File::Temp;
-use JSON::MaybeXS qw( encode_json decode_json );
-use Carp qw( carp );
-use Mojo::Util qw( monkey_patch );
-
-# ABSTRACT: Construct command line and perl clients for RESTful services.
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
 
 
 has server_url => '';
-has [qw(tx res userinfo ua )];
+has [qw(tx res userinfo client)];
 has _remote => ''; # Access via remote()
 has _cache => sub { + {} }; # cache of credentials
 
-sub client
-{
-  carp "Clustericious::Client->client is deprecated (use ua instead)";
-  shift->ua(@_);
-}
-
 sub import
 {
-  my($class) = @_;
-  my $caller = caller;
+    my $class = shift;
+    my $caller = caller;
 
-  monkey_patch $caller, route => \&route;
-  monkey_patch $caller, route_meta => \&route_meta;
-  monkey_patch $caller, route_args => \&route_args;
-  monkey_patch $caller, route_doc => sub {
-    Clustericious::Client::Meta->add_route( $caller, @_ );
-  };
-  monkey_patch $caller, object => \&object;
-  monkey_patch $caller, import => sub {};
-
-  do {
+    {
     no strict 'refs';
     push @{"${caller}::ISA"}, $class unless $caller->isa($class);
-  };
+    *{"${caller}::route"} = \&route;
+    *{"${caller}::route_meta"} = \&route_meta;
+    *{"${caller}::route_args"} = \&route_args;
+    *{"${caller}::route_doc"} = sub {
+        Clustericious::Client::Meta->add_route( $caller, @_ )
+    };
+    *{"${caller}::object"} = \&object;
+    *{"${caller}::import"} = sub {};
+    }
 }
 
 
@@ -66,44 +58,40 @@ sub _mojo_user_agent_factory
 
 sub new
 {
-  my($class, %args) = @_;
+    my $self = shift->SUPER::new(@_);
+    my %args = @_;
 
-  my $config = delete $args{config};
-  
-  my $self = $class->SUPER::new(%args);
-
-  $self->{_base_config} = $config if $config;
-
-  if($self->{app})
-  {
-    my $app = $self->{app};
-    $app = $app->new() unless ref($app);
-    my $ua = $self->_mojo_user_agent_factory();
-    return undef unless $ua;
-    eval { $ua->server->app($app) } // $ua->app($app);
-    $self->ua($ua);
-  }
-  else
-  {
-    $self->ua($self->_mojo_user_agent_factory());
-    unless(length $self->server_url)
+    if ($self->{app})
     {
-      my $url = $self->config->url;
-      $url =~ s{/$}{};
-      $self->server_url($url);
+        my $app = $self->{app};
+        $app = $app->new() unless ref($app);
+        my $client = $self->_mojo_user_agent_factory();
+        return undef unless $client;
+        eval { $client->server->app($app) } // $client->app($app);
+
+        $self->client($client);
+    }
+    else
+    {
+        $self->client($self->_mojo_user_agent_factory());
+        if (not length $self->server_url)
+        {
+            my $url = $self->_config->url;
+            $url =~ s{/$}{};
+            $self->server_url($url);
+        }
     }
-  }
 
-  my $ua = $self->ua;
-  $ua->transactor->name($self->user_agent_string);
-  $ua->inactivity_timeout($ENV{CLUSTERICIOUS_KEEP_ALIVE_TIMEOUT} || 300);
+    my $client = $self->client;
+    $client->transactor->name($self->user_agent_string);
+    $client->inactivity_timeout($ENV{CLUSTERICIOUS_KEEP_ALIVE_TIMEOUT} || 300);
 
-  if(eval { require Clustericious::Client::Local; })
-  {
-    Clustericious::Client::Local->local($self);
-  }
+    if(eval { require Clustericious::Client::Local; })
+    {
+        Clustericious::Client::Local->local($self);
+    }
 
-  $self;
+    return $self;
 }
 
 
@@ -114,7 +102,7 @@ sub remote {
     my $remote = shift;
     unless ($remote) { # reset to default
         $self->{_remote} = '';
-        $self->server_url($self->config->url);
+        $self->server_url($self->_config->url);
         return;
     }
     my $info = $self->_base_config->remotes->$remote;
@@ -138,16 +126,16 @@ sub login {
     my ($user,$pw) =
            @_==2 ? @_
          : @_    ?  @args{qw/username password/}
-         : map $self->config->$_, qw/username password/;
+         : map $self->_config->$_, qw/username password/;
     $self->userinfo(join ':', $user,$pw);
 }
 
 
 sub errorstring {
     my $self = shift;
-    WARN "Missing response in ua object" unless $self->res;
+    WARN "Missing response in client object" unless $self->res;
     return unless $self->res;
-    return if $self->res->code && $self->res->is_success;
+    return if $self->res->code && $self->res->is_status_class(200);
     my $error = $self->res->error;
     if(defined $error->{advice})
     {
@@ -168,7 +156,7 @@ sub has_error {
     my $c = shift;
     return unless $c->tx || $c->res;
     return 1 if $c->tx && $c->tx->error;
-    return 1 if $c->res && !$c->res->is_success;
+    return 1 if $c->res && !$c->res->is_status_class(200);
     return 0;
 }
 
@@ -401,11 +389,11 @@ sub _doit {
         $body = encode_json $body;
     }
 
-    return $self->ua->build_tx($method, $url, $headers, $body, $cb) if $cb;
+    return $self->client->build_tx($method, $url, $headers, $body, $cb) if $cb;
 
-    my $tx = $self->ua->build_tx($method, $url, $headers, $body);
+    my $tx = $self->client->build_tx($method, $url, $headers, $body);
 
-    $tx = $self->ua->start($tx);
+    $tx = $self->client->start($tx);
     my $res = $tx->res;
     $self->res($res);
     $self->tx($tx);
@@ -420,7 +408,7 @@ sub _doit {
         return $self->_doit($meta ? $meta : (), @_);
     }
 
-    if ($res->is_success) {
+    if ($res->is_status_class(200)) {
         TRACE "Got response : ".$res->to_string;
         my $content_type = $res->headers->content_type || do {
             WARN "No content-type from "._sanitize_url($url);
@@ -458,7 +446,7 @@ sub _doit {
         ERROR $res->body if $res->body;
         return undef;
     }
-    my $failover_urls = $self->config->failover_urls(default => []);
+    my $failover_urls = $self->_config->failover_urls(default => []);
     unless (@$failover_urls) {
         ERROR $msg;
         return undef;
@@ -481,12 +469,12 @@ sub _mycallback
     my $cb = shift;
     sub
     {
-        my ($ua, $tx) = @_;
+        my ($client, $tx) = @_;
 
         $self->res($tx->res);
         $self->tx($tx);
 
-        if ($tx->res->is_success)
+        if ($tx->res->is_status_class(200))
         {
             my $body = $tx->res->headers->content_type =~ qr[application/json]
                 ? decode_json($tx->res->body) : $tx->res->body;
@@ -507,61 +495,42 @@ sub _sanitize_url {
     return $url unless $url->userinfo;
     my $c = $url->clone;
     $c->userinfo("user:*****");
-    $c;
+    return $c;
 }
 
-sub _appname
-{
-  my($self) = @_;
-  (my $appname = ref $self) =~ s/:.*$//;
-  $appname;
+sub _appname {
+    my $self = shift;
+    (my $appname = ref $self) =~ s/:.*$//;
+    return $appname;
 }
 
-
-sub config
-{
-  my($self) = @_;  
-  my $conf = $self->_base_config;
-  if (my $remote = $self->_remote)
-  {
-    return $conf->remotes->$remote;
-  }
-  $conf;
+sub _config {
+    my $self = shift;
+    my $conf = $self->_base_config;
+    if (my $remote = $self->_remote) {
+        return $conf->remotes->$remote;
+    }
+    return $conf;
 }
 
-sub _config
-{
-  carp "Clustericious::Client->_config has been deprecated use config instead";
-  shift->config(@_);
+sub _base_config {
+    # Independent of remotes
+    my $self = shift;
+    return $self->{_base_config} if defined($self->{_base_config});
+    $self->{_base_config} = Clustericious::Config->new($self->_appname);
+    return $self->{_base_config};
 }
 
-sub _base_config
-{
-  # Independent of remotes
-  my($self) = @_;
-  unless(defined $self->{_base_config})
-  {
-    my $config_name = ref $self;
-    $config_name =~ s/::Client$//;
-    $config_name =~ s/::/-/;
-    $self->{_base_config} = Clustericious::Config->new($config_name);
-    $self->{_base_config}->{url} //= Clustericious->_default_url($config_name);
-  }
-  
-  $self->{_base_config};
+sub _has_auth {
+    my $self = shift;
+    return 0 unless $self->_config->username(default => '');
+    return 0 unless $self->_config->password(default => '');
+    return 1;
 }
 
-sub _has_auth
-{
-  my($self) = @_;
-  my $config = $self->config;
-  $config->username(default => '') && password(default => '') ? 1 : 0;
-}
-
-sub _can_auth
-{
-  my $self = shift;
-  -t STDIN ? 1 : 0;
+sub _can_auth {
+    my $self = shift;
+    return -t STDIN ? 1 : 0;
 }
 
 sub _get_user_pw  {
@@ -603,7 +572,7 @@ sub version {
 sub status {
     my $self = shift;
     my $meta = $self->meta_for("status");
-    $meta->set(auto_failover => 0);
+    $meta->set(auto_failover => 1);
     $self->_doit($meta, GET => '/status');
 }
 
@@ -637,7 +606,7 @@ Clustericious::Client - Construct command line and perl clients for RESTful serv
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -705,6 +674,8 @@ From the command line :
 
 =head1 DESCRIPTION
 
+This is a beta release.  The API is subject to changes without notice.
+
 Clustericious::Client is library for construction clients for RESTful
 services.  It provides a mapping between command line arguments, method
 arguments, and URLs.
@@ -719,20 +690,10 @@ a data structure if it is application/json.
 This class inherits from L<Mojo::Base>, and handles attributes like
 that class.  The following additional attributes are used.
 
-=head2 config
-
-Configuration object.  Defaults to the appropriate L<Clustericious::Config>
-class.
-
-=head2 ua
-
-User agent to process the HTTP stuff with.  Defaults to a
-L<Mojo::UserAgent>.
-
 =head2 client
 
-Deprecated alias for L</ua> above.  Do not use in new code.  May be removed
-in the future.
+A client to process the HTTP stuff with.  Defaults to a
+L<Mojo::UserAgent>.
 
 =head2 app
 
@@ -1011,7 +972,7 @@ Returns a Clustericious::Client::Meta::Route object.
 =head1 COMMON ROUTES
 
 These are routes that are automatically supported by all clients.
-See L<Clustericious::Plugin::CommonRoutes>.
+See L<Clustericious::RouteBuilder::Common>.
 
 =head2 version
 
@@ -1114,8 +1075,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
