@@ -4,8 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Command line type processing for clients.
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 use File::Basename qw/basename/;
@@ -38,7 +37,7 @@ EOPRINT
        $name [opts] update <object> <keys> [<filename>]
        $name [opts] delete <object> <keys>
 
-    where "opts" are as described in Clustericious::Log::CommandLine, or
+    where "opts" are as described in Log::Log4perl::CommandLine, or
     may be "--remote <remote>" to specify a remote to use from the
     config file (see Clustericious::Client).
 
@@ -97,6 +96,7 @@ sub run {
     my $class = shift;
     my $client = shift;
     my @args = @_ ? @_ : @ARGV;
+    our $TESTING;
 
     return $class->_usage($client) if !$args[0] || $args[0] =~ /help/;
 
@@ -164,7 +164,7 @@ sub run {
             }
             INFO $msg;
         } else {
-           print _prettyDump($obj);
+           print _prettyDump($obj) unless $TESTING;
         }
         return;
     }
@@ -223,7 +223,7 @@ sub run {
             }
             INFO $msg;
         } else {
-           print _prettyDump($obj);
+           print _prettyDump($obj) unless $TESTING;
         }
     }
     return;
@@ -250,7 +250,7 @@ Clustericious::Client::Command - Command line type processing for clients.
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -284,9 +284,13 @@ is a filename (i.e. is it a YAML file that should be parsed and send
 as a hashref, or a filename that should be PUT?  Should STDIN be
 used?).  These need to be formalized and documented.
 
+=head1 NOTES
+
+This is a beta release, the API is subject to change without notice.
+
 =head1 METHODS
 
-=head2 run
+=head2 C<run>
 
  Clustericious::Client::Command->run(Some::Clustericious::Client->new, @ARGV);
 
@@ -300,8 +304,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
