@@ -4,8 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: simple meta object for constructing clients
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 our %Routes; # hash from class name to array ref of routes.
 our %RouteAttributes; # hash from class name to hash ref of attributes.
@@ -91,7 +90,7 @@ Clustericious::Client::Meta - simple meta object for constructing clients
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 METHODS
 
@@ -183,8 +182,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
