@@ -11,8 +11,7 @@ use Clustericious::Log;
 use Clustericious::Client::Meta;
 
 # ABSTRACT: metadata about a route'
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has 'client_class';
@@ -179,7 +178,7 @@ Clustericious::Client::Meta::Route - metadata about a route'
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -258,8 +257,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
