@@ -4,8 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Clustericious DateTime object
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 use DateTime::Format::ISO8601;
@@ -33,7 +32,7 @@ Clustericious::Client::Object::DateTime - Clustericious DateTime object
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -64,8 +63,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
