@@ -5,8 +5,8 @@ use warnings;
 use Mojo::Base 'Mojolicious::Command';
 
 # ABSTRACT: Command base class
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
+
 
 
 1;
@@ -23,7 +23,11 @@ Clustericious::Command - Command base class
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
+
+=head1 SYNOPSIS
+
+ use Mojo::Base 'Mojolicious::Command';
 
 =head1 DESCRIPTION
 
@@ -39,23 +43,19 @@ This is a (not exhaustive) list of common Clustericious commands:
 
 =item *
 
-L<apache|Clustericious::Command::apache>
+L<hypnotoad|Clustericious::Command::hypnotoad>
 
 =item *
 
-L<configdebug|Clustericious::Command::configdebug>
+L<start|Clustericious::Command::start>
 
 =item *
 
-L<configpath|Clustericious::Command::configpath>
+L<stop|Clustericious::Command::stop>
 
 =item *
 
-L<configtest|Clustericious::Command::configtest>
-
-=item *
-
-L<configure|Clustericious::Command::configure>
+L<status|Clustericious::Command::status>
 
 =item *
 
@@ -67,30 +67,14 @@ L<generate client|Clustericious::Command::generate::client>
 
 =item *
 
-L<hypnotoad|Clustericious::Command::hypnotoad>
-
-=item *
-
-L<lighttpd|Clustericious::Command::lighttpd>
-
-=item *
-
-L<plackup|Clustericious::Command::plackup>
-
-=item *
-
-L<start|Clustericious::Command::start>
-
-=item *
-
-L<status|Clustericious::Command::status>
-
-=item *
-
-L<stop|Clustericious::Command::stop>
+L<generate mbd_app|Clustericious::Command::generate::mbd_app>
 
 =back
 
+=head1 SUPER CLASS
+
+L<Mojolicious::Command>
+
 =head1 SEE ALSO
 
 L<Clustericious>
@@ -106,8 +90,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
