@@ -8,78 +8,65 @@ use Clustericious::Config;
 use YAML::XS qw( Dump );
 
 # ABSTRACT: Debug a clustericious configuration file
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has description => <<EOT;
-Print the various stages of the clustericious app configuration file
+print the various stages of the clustericious app configuration file
 EOT
 
 has usage => <<EOT;
 usage $0: configdebug
-Print the various stages of the clustericious app configuration file
+print the various stages of the clustericious app configuration file
 EOT
 
 sub run
 {
-  my($self, $name) = @_;
-  my $app_name = $name // ref($self->app);
+  my $self = shift;
+  my $app_name = $_[0] || ref($self->app);
 
   $ENV{MOJO_TEMPLATE_DEBUG} = 1;
+  $ENV{CLUSTERICIOUS_CONFIG_SAVE_RENDERED} = 1;
 
-  my $exit = 0;
-
-  eval { 
-    my $config = Clustericious::Config->new($app_name, sub {
-      my $type = shift;
-
-      if($type eq 'pre_rendered')
-      {
-        my($src) = @_;
-        my $data;
-        if(ref $src)
-        {
-          say "[SCALAR :: template]";
-          $data = $$src;
-        }
-        else
-        {
-          say "[$src :: template]";
-          open my $fh, '<', $src;
-          local $/;
-          $data = <$fh>;
-          close $fh;
-        }
-        chomp $data;
-        say $data;
-      }
-      elsif($type eq 'rendered')
-      {
-        my($file, $content) = @_;
-        say "[$file :: interpreted]";
-        chomp $content;
-        say $content;
-      }
-      elsif($type eq 'not_found')
-      {
-        say STDERR "ERROR: unable to find $_[0]";
-        $exit = 2;
-      }
-    });
-
-    say "[merged]";
-    print Dump({ %$config });
-
-  };
-  
-  if(my $error = $@)
+  my $callback1 = sub
   {
-    say STDERR "ERROR: in syntax: $error";
-    $exit = 2;
-  }
+    my($class, $src) = @_;
+    my $data;
+    if(ref $src)
+    {
+      say "[SCALAR :: template]";
+      $data = $$src;
+    }
+    else
+    {
+      say "[$src :: template]";
+      open my $fh, '<', $src;
+      local $/;
+      $data = <$fh>;
+      close $fh;
+    }
+    chomp $data;
+    say $data;
+  };
+
+  my $callback2 = sub
+  {
+    my($class, $file, $content) = @_;
+    say "[$file :: interpreted]";
+    chomp $content;
+    say $content;
+  };
+
+  # place the hooks in Clustericious::Config which usually
+  # doesn't do this debugging stuff.
+  do { no warnings; *Clustericious::Config::pre_rendered = $callback1; };
+  do { no warnings; *Clustericious::Config::rendered     = $callback2; };
+
+  my $config = Clustericious::Config->new($app_name);
+
+  say "[merged]";
+  print Dump({ %$config });
 
-  exit $exit;
 };
 
 1;
@@ -96,7 +83,7 @@ Clustericious::Command::configdebug - Debug a clustericious configuration file
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -143,8 +130,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
