@@ -6,23 +6,27 @@ use 5.010;
 use Mojo::Base 'Clustericious::Command';
 
 # ABSTRACT: Test a Clustericious application's configuration
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has description => <<EOT;
-Load configuration and test for errors
+load configuration and test for errors
 EOT
 
 has usage => <<EOT;
 usage $0: configtest
-Load configuration and test for errors
+load configuration and test for errors
 EOT
 
 sub run
 {
-  my($self, @args) = @_;
-  exit 2 unless $self->app->sanity_check;
+  my $self = shift;
+  my @args = @_ ? @_ : @ARGV;
+  
+  my $app = $self->app;
+  
+  exit 2 unless $app->sanity_check;
+  
   say 'config okay';
 }
 
@@ -40,7 +44,7 @@ Clustericious::Command::configtest - Test a Clustericious application's configur
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -74,6 +78,10 @@ do a sanity check of the configuration:
 This command does a basic sanity check on the configuration for your Clustericious
 application, and calls the application's C<sanity_check>
 
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
 =head1 SEE ALSO
 
 L<Clustericious>
@@ -88,8 +96,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
