@@ -4,11 +4,10 @@ use strict;
 use warnings;
 use 5.010;
 use Mojo::Base 'Clustericious::Command';
-use Path::Class qw( dir );
+use Path::Class qw/dir/;
 
 # ABSTRACT: Generate a default configuration.
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has description => <<EOT;
@@ -21,27 +20,28 @@ EOT
 
 sub run
 {
-  my($self, @args) = @_;
+  my $self = shift;
+  my @args = @_ ? @_ : @ARGV;
 
   my $root = dir($ENV{CLUSTERICIOUS_CONF_DIR} || $ENV{HOME});
   my $conf = $self->app->generate_config(@args);
 
   for my $d (@{$conf->{dirs} || []}) {
-    my $dir = dir($root, @$d);
-    -d $dir and do { say "-> exists : $dir"; next; };
-    my @made = $dir->mkpath;
-    say "-> mkdir $_" for @made;
+      my $dir = dir($root, @$d);
+      -d $dir and do { say "-> exists : $dir"; next; };
+      my @made = $dir->mkpath;
+      say "-> mkdir $_" for @made;
   }
   
   my $config_root = dir($root)->subdir('etc');
   for my $filename (keys %{$conf->{files}}) {
-    my $file = $config_root->file($filename);
-    -e $file and do {
-      say "-> exists : $file";
-      next;
-    };
-    say "-> write $file";
-    $file->spew($conf->{files}{$filename});
+      my $file = $config_root->file($filename);
+      -e $file and do {
+          say "-> exists : $file";
+          next;
+      };
+      say "-> write $file";
+      $file->spew($conf->{files}{$filename});
   }
 
   1;
@@ -61,7 +61,7 @@ Clustericious::Command::configure - Generate a default configuration.
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -83,7 +83,7 @@ Your app:
         files => { 'YourApp.conf' => <<<CUT }
  ---
  required_key   : default_value
- something_else : <%= home %>
+ something_else : <%= $ENV{HOME} %>
  CUT
    };
  }
@@ -94,6 +94,10 @@ Your app:
 
 Create a default configuration for an app.
 
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
 =head1 SEE ALSO
 
 L<Clustericious>
@@ -108,8 +112,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
