@@ -5,8 +5,7 @@ use warnings;
 use Mojo::Base 'Mojolicious::Command::generate';
 
 # ABSTRACT: Clustericious code generation commands.
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has namespaces =>
@@ -28,12 +27,11 @@ Clustericious::Command::generate - Clustericious code generation commands.
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
- % clustericious generate app MyApp
- % clustericious generate client MyApp
+ % clustericious generate mbd_app Myapp --schema schema.sql
 
 =head1 DESCRIPTION
 
@@ -41,6 +39,10 @@ This is the base class for all Clustericious code generation commands.
 It inherits from L<Mojolicious::Command::generate> instead of
 L<Clustericious::Command>.
 
+=head1 SUPER CLASS
+
+L<Mojolicious::Command::generate>
+
 =head1 SEE ALSO
 
 L<Clustericious>
@@ -55,8 +57,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
