@@ -2,13 +2,13 @@ package Clustericious::Command::generate::app;
 
 use strict;
 use warnings;
-use Clustericious;
 use Mojo::Base 'Clustericious::Command';
 use File::Find;
+use File::ShareDir 'dist_dir';
+use File::Basename qw/basename/;
 
 # ABSTRACT: Clustericious command to generate a new Clustericious application
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has description => <<'EOF';
@@ -21,37 +21,38 @@ EOF
 
 sub _installfile
 {
-  my $self = shift;
-  my ($templatedir, $file, $class) = @_;
+    my $self = shift;
+    my ($templatedir, $file, $class) = @_;
 
-  my $name = lc $class;
+    my $name = lc $class;
 
-  (my $relpath = $file) =~ s/^$templatedir/$class/;
-  $relpath =~ s/APPCLASS/$class/g;
-  $relpath =~ s/APPNAME/$name/g;
+    (my $relpath = $file) =~ s/^$templatedir/$class/;
+    $relpath =~ s/APPCLASS/$class/g;
+    $relpath =~ s/APPNAME/$name/g;
 
-  return if -e $relpath;
+    return if -e $relpath;
 
-  my $content = Mojo::Template->new->render_file( $file, $class );
-  $self->write_file($relpath, $content );
-  -x $file && $self->chmod_file($relpath, 0755);
+    my $content = Mojo::Template->new->render_file( $file, $class );
+    $self->write_file($relpath, $content );
+    -x $file && $self->chmod_file($relpath, 0744);
 }
 
 sub run
 {
-  my ($self, $class, @args ) = @_;
-  $class ||= 'MyClustericiousApp';
-  if (@args % 2) {
-    die "usage : $0 generate app <name>\n";
-  }
-  my %args = @args;
+    my ($self, $class, @args ) = @_;
+    $class ||= 'MyClustericiousApp';
+    if (@args % 2) {
+        die "usage : $0 generate app <name> --schema <schema>.sql\n";
+    }
+    my %args = @args;
 
-  my $templatedir = Clustericious->_dist_dir->subdir('tmpl', '1.08', 'app');
+    my $templatedir = dist_dir('Clustericious') . "/AppTemplate";
 
-  die "Can't find template.\n" unless -d $templatedir;
+    die "Can't find template.\n" unless -d $templatedir;
+
+    find({wanted => sub { $self->_installfile($templatedir, $_, $class) if -f },
+          no_chdir => 1}, $templatedir);
 
-  find({wanted => sub { $self->_installfile($templatedir, $_, $class) if -f },
-        no_chdir => 1}, $templatedir);
 }
 
 1;
@@ -68,7 +69,7 @@ Clustericious::Command::generate::app - Clustericious command to generate a new
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -78,6 +79,10 @@ version 1.28_01
 
 This command generates a new Clustericious application with the given name.
 
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
 =head1 SEE ALSO
 
 L<Clustericious>
@@ -92,8 +97,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
