@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use Mojo::Base 'Clustericious::Command';
 use File::Find;
-use File::Basename qw( basename );
+use File::ShareDir 'dist_dir';
+use File::Basename qw/basename/;
 
 # ABSTRACT: Clustericious command to generate a new Clustericious client
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has description => <<'EOF';
@@ -21,42 +21,42 @@ EOF
 
 sub _installfile
 {
-  my $self = shift;
-  my ($templatedir, $file, $serverclass, $moduledir) = @_;
+    my $self = shift;
+    my ($templatedir, $file, $serverclass, $moduledir) = @_;
 
-  my $name = lc $serverclass;
+    my $name = lc $serverclass;
 
-  (my $relpath = $file) =~ s/^$templatedir/$moduledir/;
-  $relpath =~ s/APPCLASS/$serverclass/g;
-  $relpath =~ s/APPNAME/$name/g;
+    (my $relpath = $file) =~ s/^$templatedir/$moduledir/;
+    $relpath =~ s/APPCLASS/$serverclass/g;
+    $relpath =~ s/APPNAME/$name/g;
 
-  return if -e $relpath;
+    return if -e $relpath;
 
-  my $content = Mojo::Template->new->render_file( $file, $serverclass );
-  $self->write_file($relpath, $content );
-  -x $file && $self->chmod_file($relpath, 0755);
+    my $content = Mojo::Template->new->render_file( $file, $serverclass );
+    $self->write_file($relpath, $content );
+    -x $file && $self->chmod_file($relpath, 0744);
 }
 
 sub run
 {
-  my ($self, $serverclass, @args ) = @_;
-  $serverclass ||= 'MyClustericiousApp';
-  if (@args % 2)
-  {
-    die "usage : $0 generate client <app_name>\n";
-  }
-  my %args = @args;
+    my ($self, $serverclass, @args ) = @_;
+    $serverclass ||= 'MyClustericiousApp';
+    if (@args % 2) {
+        die "usage : $0 generate client <app_name>\n";
+    }
+    my %args = @args;
 
-  die "app_name should be the server name" if $serverclass =~ /\-/;
+    die "app_name should be the server name" if $serverclass =~ /\-/;
 
-  my $moduledir = $serverclass.'-Client';
+    my $moduledir = $serverclass.'-Client';
 
-  my $templatedir = Clustericious->_dist_dir->subdir('tmpl', '1.08', 'client');
+    my $templatedir = dist_dir('Clustericious') . "/ClientTemplate";
 
-  die "Can't find template in $templatedir.\n" unless -d $templatedir;
+    die "Can't find template in $templatedir.\n" unless -d $templatedir;
+
+    find({wanted => sub { $self->_installfile($templatedir, $_, $serverclass, $moduledir) if -f },
+          no_chdir => 1}, $templatedir);
 
-  find({wanted => sub { $self->_installfile($templatedir, $_, $serverclass, $moduledir) if -f },
-        no_chdir => 1}, $templatedir);
 }
 
 1;
@@ -73,7 +73,7 @@ Clustericious::Command::generate::client - Clustericious command to generate a n
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -83,6 +83,10 @@ version 1.28_01
 
 This command generates a new Clustericious client with the given name.
 
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
 =head1 SEE ALSO
 
 L<Clustericious>, L<Clustericious::Client>
@@ -97,8 +101,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
