@@ -6,12 +6,9 @@ use Clustericious::Log;
 use Clustericious::App;
 use Mojo::Server::PSGI;
 use base 'Clustericious::Command';
-use File::Which qw( which );
-use Mojo::URL;
 
 # ABSTRACT: Clustericious command to start plack server
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 __PACKAGE__->attr(description => <<EOT);
@@ -24,29 +21,21 @@ Starts a plack server.  See plackup for valid options.
 EOT
 
 sub run {
-  my($self, @args) = @_;
-  my $app_name = $ENV{MOJO_APP};
-  
-  $self->app->init_logging;
+    my $self = shift;
+    my @args = @_ ? @_ : @ARGV;
+    my $app_name = $ENV{MOJO_APP};
+    my $conf = Clustericious::Config->new( $app_name );
 
-  my $plackup = which('plackup') || LOGDIE "could not find plackup in $ENV{PATH}";
+    Clustericious::App->init_logging;
 
-  my $url = Mojo::URL->new($self->app->config->url);
-  LOGDIE "@{[ $url->scheme ]} not supported" if $url->scheme ne 'http';
-  
-  shift @args if defined $args[0] && $args[0] eq 'plackup';
-  push @args, $0;
-  unshift @args, '--port' => $url->port;
-  unshift @args, '--host' => $url->host;
-  
-  #if(my $pid_file = $self->app->config->plackup(default => {})->pid_file(default => 0))
-  #{
-  #  unshift @args, '--pidfile' => $pid_file;
-  #}
-  
-  DEBUG "starting $plackup @args";
-  delete $ENV{MOJO_COMMANDS_DONE};
-  exec $plackup, @args;
+    my $plackup = qx[which plackup] or LOGDIE "could not find plackup in $ENV{PATH}";
+    chomp $plackup;
+
+    DEBUG "starting $plackup @args";
+    delete $ENV{MOJO_COMMANDS_DONE};
+    system( $plackup, @args ) == 0
+      or die "could not start $plackup @args ($?) "
+      . ( ${^CHILD_ERROR_NATIVE} || '' );
 }
 
 1;
@@ -63,17 +52,19 @@ Clustericious::Command::plackup - Clustericious command to start plack server
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
- % yourapp plackup
+ % yourapp start
 
 =head1 DESCRIPTION
 
-Start a plack server using plackup.  By default plackup does not daemonize into the
-background, making it a handy development server.  Any arguments will be passed into
-the plackup command directly.
+Start a plack server using plackup.
+
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
 
 =head1 SEE ALSO
 
@@ -89,8 +80,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
