@@ -3,18 +3,15 @@ package Clustericious::Command::start;
 use strict;
 use warnings;
 use Clustericious::Log;
-use File::Path qw( mkpath );
-use File::Basename qw( dirname );
+use List::MoreUtils qw/mesh/;
+use File::Path qw/mkpath/;
+use File::Basename qw/dirname/;
 use Clustericious::App;
 use Clustericious::Config;
 use Mojo::Base 'Clustericious::Command';
-use Text::ParseWords qw( shellwords );
-use Carp ();
-use Env qw( @PERL5LIB );
 
 # ABSTRACT: Clustericious command to start a Clustericious application
-our $VERSION = '1.28_01'; # TRIAL VERSION 
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION 
 
 
 has description => <<EOT;
@@ -29,58 +26,56 @@ See Clustericious::Command::Start for examples.
 EOT
 
 sub run {
-  my($self, @args) = @_;
-  exit 2 unless $self->app->sanity_check;
-  my $app  = $ENV{MOJO_APP};
-  my $conf     = $self->app->config;
+    my $self     = shift;
+    exit 2 unless $self->app->sanity_check;
+    my @args = @_ ? @_ : @ARGV;
+    my $app  = $ENV{MOJO_APP};
+    my $conf     = Clustericious::Config->new( $app );
 
-  eval "use $app;";
-  die $@ if $@;
-
-  $self->app->init_logging;
-
-  for my $mode ($self->app->config->start_mode)
-  {
-    INFO "Starting $mode";
-    my %conf = $conf->$mode;
-    if(my $autogen = delete $conf{autogen})
-    {
-      $autogen = [ $autogen ] if ref $autogen eq 'HASH';
-      for my $i (@$autogen)
-      {
-        DEBUG "autowriting ".$i->{filename};
-        mkpath(dirname($i->{filename}), 0, 0700);
-        open my $fp, ">$i->{filename}" or LOGDIE "cannot write to $i->{filename} : $!";
-        print $fp $i->{content};
-        close $fp or LOGDIE $!;
-      }
+    local $SIG{__DIE__} = \&Carp::confess;
+    eval "use $app;";
+    if ($@) {
+        die "\n----------Error loading $app----------\n$@\n--------------\n";
     }
 
-    # env hash goes to the environment
-    my $env = delete $conf{env} || {};
-    @ENV{ keys %$env } = values %$env;
-    if($env->{PERL5LIB})
-    {
-      # Do it now, in case we are not spawning a new process.
-      push @INC, @PERL5LIB;
-    }
-    TRACE "Setting env vars : ".join ',', keys %$env;
+    Clustericious::App->init_logging;
 
-    my @args;
+    for my $mode ($conf->start_mode) {
+        #  local %ENV = %ENV;
+        INFO "Starting $mode";
+        my %conf = $conf->$mode;
+        if (my $autogen = delete $conf{autogen}) {
+            $autogen = [ $autogen ] if ref $autogen eq 'HASH';
+            for my $i (@$autogen) {
+                DEBUG "autowriting ".$i->{filename};
+                mkpath dirname($i->{filename});
+                open my $fp, ">$i->{filename}" or LOGDIE "cannot write to $i->{filename} : $!";
+                print $fp $i->{content};
+                close $fp or LOGDIE $!;
+            }
+        }
 
-    if(my $args = delete $conf{args})
-    {
-      @args = ref $args ne 'ARRAY' ? (shellwords $args) : @$args;
-    }
-    elsif(%conf)
-    {
-      die "arguments specified withouth 'args' option\n";
-    }
+        # env hash goes to the environment
+        my $env = delete $conf{env} || {};
+        @ENV{ keys %$env } = values %$env;
+        if ($env->{PERL5LIB}) {
+            # Do it now, in case we are not spawning a new process.
+            push @INC, split /:/, $env->{PERL5LIB};
+        }
+        TRACE "Setting env vars : ".join ',', keys %$env;
 
-    DEBUG "Sending args for $mode : @args";
-    $ENV{MOJO_COMMANDS_DONE} = 0;
-    Clustericious::Commands->start($mode,@args);
-  }
+        # if it starts with a dash, leave it alone, else add two dashes
+        my %args = mesh
+          @{ [ map {/^-/ ? "$_" : "--$_"} keys %conf ] },
+          @{ [ values %conf                          ] };
+
+        # squash "null"s (for boolean arguments)
+        my @args = grep { $_ ne 'null' } %args;
+        DEBUG "Sending args for $mode : @args";
+
+        $ENV{MOJO_COMMANDS_DONE} = 0;
+        Clustericious::Commands->start($mode,@args);
+    }
 }
 
 1;
@@ -97,7 +92,7 @@ Clustericious::Command::start - Clustericious command to start a Clustericious a
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -138,6 +133,10 @@ to set before starting the command.
 
 Clustericious::Command::start - Clustericious command to start a Clustericious application
 
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
 =head1 SEE ALSO
 
 L<Clustericious>,
@@ -153,8 +152,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
