@@ -6,8 +6,7 @@ use Clustericious::Config;
 use Mojo::Base 'Mojolicious::Commands';
 
 # ABSTRACT: Clustericious command runner
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has namespaces => sub { [qw/Clustericious::Command Mojolicious::Command/] };
@@ -39,7 +38,7 @@ Clustericious::Commands - Clustericious command runner
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -68,8 +67,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
