@@ -3,10 +3,9 @@ package Clustericious::Config::Plugin;
 use strict;
 use warnings;
 use Clustericious::Config::Helpers;
-use Carp ();
 
 # ABSTRACT: Deprecated module
-our $VERSION = '1.10_04'; # TRIAL VERSION
+our $VERSION = '1.01'; # VERSION
 
 
 # Hack to keep old versions of Test::Clustericious::Cluster working
@@ -17,14 +16,6 @@ sub Clustericious::Config::Helpers::cluster
   goto &Clustericious::Config::Plugin::cluster;
 }
 
-Carp::carp "Clustericious::Config::Plugin is deprecated and will be removed on or after January 31 2016";
-
-if(scalar caller eq 'Test::Clustericious::Cluster')
-{
-  Carp::carp "Upgrade your version of Test::Clustericious::Cluster, otherwise it will stop working when Clustericious::Config::Plugin is removed";
-}
-
-
 1;
 
 __END__
@@ -39,7 +30,7 @@ Clustericious::Config::Plugin - Deprecated module
 
 =head1 VERSION
 
-version 1.10_04
+version 1.01
 
 =head1 DESCRIPTION
 
