@@ -4,24 +4,16 @@ use strict;
 use warnings;
 use Clustericious::Config;
 use Clustericious::Log;
-use Carp qw( carp );
 use base 'Mojolicious::Controller';
 
 # ABSTRACT: Clustericious controller base class
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 sub url_for {
     my $c = shift;
 
-    # NOTE: the only place it looks like we need to use this bizzarely 
-    # customized url_for is in Restmd.  If we can confirm/deny that we
-    # do/don't need it there, then we can probably remove this special case
-    # NOTE2: also used in the function below.
-
-    # Note: This dos not seem to be the case anymore:
-    # Original Comment: link_to calls url_for on a Mojo::URL which for some reason
+    # link_to calls url_for on a Mojo::URL which for some reason
     # causes /a/b?c=d to not work properly (? is escaped)
     return $_[0] if @_==1 && ref($_[0]) eq "Mojo::URL";
 
@@ -59,6 +51,10 @@ sub redirect_to {
     return $self;
 }
 
+
+sub render_text { shift->render( text => @_ ) };
+sub render_json { shift->render( json => @_ ) };
+
 1;
 
 __END__
@@ -73,7 +69,7 @@ Clustericious::Controller - Clustericious controller base class
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -89,7 +85,7 @@ L<Mojolicious::Controller>
 
 =head1 METHODS
 
-=head2 url_for
+=head2 $c-E<gt>url_for
 
 Clustericious version of this method usually provided by Mojolicious.
 
@@ -104,6 +100,18 @@ It does this by explicitly using the url_base from the
 Clustericious config file for the app as the base for
 the location header.
 
+=head2 $c-E<gt>render_text
+
+Previous versions of Mojolicious included this
+method, and it was added here to ease the transition.  This method should be considered
+deprecated and may be removed in the future.
+
+=head2 $c-E<gt>render_json
+
+Previous versions of Mojolicious included this
+method, and it was added here to ease the transition.  This method should be considered
+deprecated and may be removed in the future.
+
 =head1 SEE ALSO
 
 L<Clustericious>
@@ -118,8 +126,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
