@@ -6,16 +6,14 @@ use Mojo::Base 'Clustericious::App';
 use Clustericious::RouteBuilder qw/Clustericious::HelloWorld/;
 
 # ABSTRACT: Clustericious hello world application
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
-get '/' => sub { shift->render(text => 'Hello, world') } => 'index';
+BEGIN {
+    $ENV{LOG_LEVEL} = 'FATAL';
+}
 
-get '/modules' => sub {
-  my %copy = %INC;
-  shift->stash->{autodata} = \%copy;
-} => 'modules';
+any '/*foo' => {foo => '', text => 'Clustericious is working!'};
 
 1;
 
@@ -31,7 +29,7 @@ Clustericious::HelloWorld - Clustericious hello world application
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -59,8 +57,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
