@@ -6,11 +6,10 @@ use List::Util qw( first );
 use Log::Log4perl qw( :easy );
 use MojoX::Log::Log4perl;
 use File::ReadBackwards;
-use Clustericious;
+use File::HomeDir;
 
 # ABSTRACT: A Log::Log4perl wrapper for use with Clustericious.
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 sub import {
@@ -20,8 +19,8 @@ sub import {
     if (my $app_name = $args{-init_logging}) {
         init_logging($app_name);
     }
-    @_ = ($class, ':easy');
-    goto \&Log::Log4perl::import;
+    no strict 'refs';
+    *{"${dest}::$_"} = *{"${class}::$_"} for qw/TRACE INFO DEBUG ERROR WARN FATAL LOGDIE get_logger/;
 }
 
 
@@ -35,6 +34,9 @@ sub init_logging {
     $Log::Log4perl::Logger::INITIALIZED = 0 if $initPid && $initPid != $$;
     $initPid = $$;
 
+    my $home = File::HomeDir->my_home;
+    my @Confdirs = ($home, "$home/etc", "/util/etc", "/etc" );
+
     # Logging
     $ENV{LOG_LEVEL} ||= 'WARN';
 
@@ -42,7 +44,7 @@ sub init_logging {
     my $l4p_pat; # pattern for screen logging
     my $l4p_file; # file (global or app specific)
 
-    $l4p_dir  = first { -d $_ && (-e "$_/log4perl.conf" || -e "$_/$app_name.log4perl.conf") } Clustericious->_config_path;
+    $l4p_dir  = first { -d $_ && (-e "$_/log4perl.conf" || -e "$_/$app_name.log4perl.conf") } @Confdirs;
     $l4p_pat  = "[%d] [%Z %H %P] %5p: %m%n";
     if ($l4p_dir) {
         $l4p_file = first {-e "$l4p_dir/$_"} ("$app_name.log4perl.conf", "log4perl.conf");
@@ -111,18 +113,18 @@ Clustericious::Log - A Log::Log4perl wrapper for use with Clustericious.
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
  use Clustericious::Log -init_logging => "appname";
- 
+
  use Clustericious::Log;
  INFO "Hi there!";
 
 =head1 DESCRIPTION
 
-This is a simple wrapper around L<Log::Log4perl> for use with
+This is a simple wrapper around Log::Log4perl for use with
 Clustericious.  It handles initialization and exporting of
 convenient logging functions, and a default set of logging
 patterns.  It also makes the name of the application available
@@ -130,7 +132,7 @@ for logging patterns (see the example).
 
 =head1 EXAMPLE
 
-Here is a sample C<~/etc/log4perl.conf> :
+Here is a sample ~/etc/log4perl.conf :
 
  log4perl.rootLogger=TRACE, LOGFILE
  log4perl.appender.LOGFILE=Log::Log4perl::Appender::File
@@ -146,8 +148,8 @@ Here is a sample C<~/etc/log4perl.conf> :
 
 =item init_logging
 
-Start logging.  Looks for C<log4perl.conf> or C<$app.log4perl.conf>
-in C<~/etc> and C</etc>.
+Start logging.  Looks for log4perl.conf or $app.log4perl.conf
+in ~/etc, /util/etc and /etc.
 
 =item tail
 
@@ -165,6 +167,10 @@ The following variables affect logging :
  LOG_FILE
  MOJO_APP
 
+=head1 NOTES
+
+This is a beta release, the API may change without notice.
+
 =head1 SEE ALSO
 
 L<Log::Log4perl>, L<Clustericious>
@@ -179,8 +185,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
