@@ -4,104 +4,60 @@ use strict;
 use warnings;
 use base 'Mojolicious::Plugin';
 use Mojo::ByteStream 'b';
+use JSON::XS;
+use YAML::XS qw/Dump Load/;
 use Clustericious::Log;
-use PerlX::Maybe qw( maybe );
-use Path::Class qw( dir );
 
 # ABSTRACT: Handle data types automatically
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
-sub _default_coders
-{
-  my %coders =
-    map { $_ => 1 }
-    map { $_ =~ s/\.pm$//; $_ }
-    map { $_->basename }
-    grep { ! $_->is_dir }
-    map { $_->children( no_hidden => 1 ) }
-    grep { -d $_ }
-    map { dir $_, 'Clustericious', 'Coder' } @INC;
-  [ keys %coders ];
-}
+my $default_decode = 'application/x-www-form-urlencoded';
+my $default_encode = 'application/json';
+
+my $json_encoder = JSON::XS->new->allow_nonref->allow_blessed->convert_blessed;
+
+my %types =
+(
+    'application/json' =>
+    {
+        encode => sub { $json_encoder->encode($_[0]) },
+        decode => sub { $json_encoder->decode($_[0]) }
+    },
+    'text/x-yaml' =>
+    {
+        encode => sub { Dump($_[0]) },
+        decode => sub { Load($_[0]) }
+    },
+    'application/x-www-form-urlencoded' =>
+    {
+        decode => sub { my ($data, $c) = @_; $c->req->params->to_hash }
+    }
+);
+
+my %formats =
+(
+    'json' => 'application/json',
+    'yml'  => 'text/x-yaml',
+);
 
 sub register
 {
-  my ($self, $app, $conf) = @_;
+    my ($self, $app, $conf) = @_;
 
-  my @coders = $app->isa('Clustericious::App')
-    ? $app->config->coders( default => __PACKAGE__->_default_coders )
-    : @{ $conf->{coders} // __PACKAGE__->_default_coders };
-  
-  my %types = (
-    'application/x-www-form-urlencoded' => {
-      decode => sub { my ($data, $c) = @_; $c->req->params->to_hash }
-    }
-  );
-  my %formats;
-  
-  foreach my $coder (@coders)
-  {
-    require join('/', qw( Clustericious Coder ), "$coder.pm");
-    my $coder = join('::', qw( Clustericious Coder ), $coder)->coder;
-    $types{$coder->{type}} = {
-      maybe encode => $coder->{encode},
-      maybe decode => $coder->{decode},
-    },
-    $formats{$coder->{format}} = $coder->{type}
-      if $coder->{format};
-  }
+    $default_decode = $conf->{default_decode} if $conf->{default_decode};
+    $default_encode = $conf->{default_encode} if $conf->{default_encode};
 
-  my $default_decode = $conf->{default_decode} // 'application/x-www-form-urlencoded';
-  my $default_encode = $conf->{default_encode} // 'application/json'; # TODO: not used
+    $app->renderer->add_handler('autodata' => \&_autodata_renderer);
 
-  my $find_type = sub {
-    my ($c) = @_;
+    $app->plugins->on( parse_autodata => \&_autodata_parse);
+    $app->plugins->on( add_autodata_type => \&_autodata_add);
 
-    my $headers = $c->tx->req->content->headers;
+    $app->helper( parse_autodata => \&_autodata_parse );
+}
 
-    foreach my $type (map { /^([^;]*)/ } # get only stuff before ;
-                      split(',', $headers->header('Accept') || ''),
-                      $headers->content_type || '')
-    {
-        return $type if $types{$type} and $types{$type}->{encode};
-    }
-
-    my $format = $c->stash->{format} // 'json';
-    $format = 'json' unless $formats{$format};
-
-    $formats{$format};
-  };
-
-
-  $app->renderer->add_handler('autodata' => sub {
-    my ($r, $c, $output, $data) = @_;
-
-    my $type = $find_type->($c);
-    LOGDIE "no encoder for $type" unless $types{$type}->{encode};
-    $$output = $types{$type}->{encode}->($c->stash("autodata"));
-    $c->tx->res->headers->content_type($type);
-  });
-
-  my $parse_autodata = sub {
-    my ($c) = @_;
-
-    my $content_type = $c->req->headers->content_type || $default_decode;
-    if ($content_type =~ /^([^;]+);/) {
-        # strip charset
-        $content_type = $1;
-    }
-    my $entry = $types{$content_type} || $types{$default_decode};
-
-    # TODO: avoid passing $c in, only used by
-    # application/x-www-form-urlencoded above
-    $c->stash->{autodata} = $entry->{decode}->($c->req->body, $c);
-  };
-
-  $app->plugins->on( parse_autodata => $parse_autodata );
-
-  $app->plugins->on( add_autodata_type => sub {
+sub _autodata_add
+{
     my($plugins, $args) = @_;
 
     LOGDIE "No extension provided" unless defined $args->{extension};
@@ -117,14 +73,52 @@ sub register
     if(defined $args->{decode}) {
         $types{$mime}->{decode} = $args->{decode};
     }
-  });
+}
 
-  $app->helper( parse_autodata => $parse_autodata );
-    
-  $app->hook(before_render => sub {
-    my($c, $args) = @_;
-    $c->stash->{handler} = "autodata" if exists($c->stash->{autodata}) || exists($args->{autodata});
-  });
+sub _find_type
+{
+    my ($c) = @_;
+
+    my $headers = $c->tx->req->content->headers;
+
+    foreach my $type (map { /^([^;]*)/ } # get only stuff before ;
+                      split(',', $headers->header('Accept') || ''),
+                      $headers->content_type || '') {
+        return $type if $types{$type} and $types{$type}->{encode};
+    }
+
+    my $format = $c->stash->{format} // 'json';
+    LOGDIE "No type associated with $format" unless $formats{$format};
+
+    return $formats{$format};
+}
+
+sub _autodata_renderer
+{
+    my ($r, $c, $output, $data) = @_;
+
+    my $type = _find_type($c);
+    LOGDIE "no encoder for $type" unless $types{$type}{encode};
+    $$output = $types{$type}->{encode}->($c->stash("autodata"), $c);
+
+    $c->tx->res->headers->content_type($type);
+
+    return 1;
+}
+
+sub _autodata_parse
+{
+    my ($c) = @_;
+
+    my $content_type = $c->req->headers->content_type || $default_decode;
+    if ($content_type =~ /^([^;]+);/) {
+        # strip charset
+        $content_type = $1;
+    }
+    my $entry = $types{$content_type} || $types{$default_decode};
+
+    $c->stash->{autodata} = $entry->{decode}->($c->req->body, $c);
+    return $c->stash->{autodata};
 }
 
 1;
@@ -141,7 +135,7 @@ Clustericious::Plugin::AutodataHandler - Handle data types automatically
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -151,20 +145,20 @@ version 1.28_01
  
  get '/some/route' => sub {
    my $c = shift;
-   $c->stash->{autodata} = { x => 1, y => 'hello, z => [1,2,3] };
+   $c->{autodata} = { x => 1, y => 'hello, z => [1,2,3] };
  };
 
 =head1 DESCRIPTION
 
 Adds a renderer that automatically serializes that "autodata" in the
 stash into a format based on HTTP Accept and Content-Type headers.
-Also adds a helper called C<parse_autodata> that handles incoming data by
+Also adds a helper called 'parse_autodata' that handles incoming data by
 Content-Type.
 
 Supports application/json, text/x-yaml and
 application/x-www-form-urlencoded (in-bound only).
 
-When C<parse_autodata> is called from within a route like this:
+When parse_autodata is called from within a route like this:
 
  $self->parse_autodata;
 
@@ -188,8 +182,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
