@@ -5,25 +5,22 @@ use warnings;
 use Clustericious::Log;
 use Mojo::ByteStream qw/b/;
 use Mojo::URL;
+use Clustericious::Config;
 use Mojo::Base 'Mojolicious::Plugin';
-use JSON::MaybeXS qw( encode_json );
 
 # ABSTRACT: Plugin for clustericious to use PlugAuth.
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 has 'config_url';
 
 sub register {
     my ($self, $app, $conf) = @_;
-    my $url = eval { $conf->{plug_auth}->url(default => '') };
-    $url =~ s{/$}{} if defined $url;
-    if ($@) {
+    eval { $self->config_url($conf->{plug_auth}->url(default => '')) };
+    if ($@ || !$self->config_url) {
         WARN "unable to determine PlugAuth URL: $@";
         return $self;
     }
-    $self->config_url($url);
     $self;
 }
 
@@ -37,7 +34,7 @@ sub authenticate {
     # Everyone needs to send an authorization header
     my $auth = $c->req->headers->authorization or do {
         $c->res->headers->www_authenticate(qq[Basic realm="$realm"]);
-        $c->render(text => "auth required", layout => "", status => 401);
+        $c->render_text("auth required", layout => "", status => 401);
         return;
     };
 
@@ -51,7 +48,7 @@ sub authenticate {
 
     # VIP treatment for some hosts
     my $ip = $c->tx->remote_address;
-    $c->ua->get("$config_url/host/$ip/trusted", sub {
+    $c->auth_ua->get("$config_url/host/$ip/trusted", sub {
         my $ua = shift;
     
         do {
@@ -67,11 +64,11 @@ sub authenticate {
                     WARN "PlugAuth returned code " . $res->code;
                 }
             } else {
-                my $error = $tx->error;
-                if ($error->{code}) {
-                    TRACE "Not VIP $config_url/host/$ip/trusted : @{[ $error->{code} ]} @{[ $error->{message} ]}";
+                my ( $message, $code ) = $tx->error;
+                if ($code) {
+                    TRACE "Not VIP $config_url/host/$ip/trusted : $code $message";
                 } else {
-                    WARN "Error connecting to PlugAuth at $config_url/host/$ip/trusted : @{[ encode_json $error ]}";
+                    WARN "Error connecting to PlugAuth at $config_url/host/$ip/trusted : $message";
                 }
             }
         };
@@ -92,11 +89,11 @@ sub authenticate {
 
             if(!defined $check || $check == 503) {
                 $c->res->headers->www_authenticate(qq[Basic realm="$realm"]);
-                my $error = $tx->error;
-                if ($error->{code}) {
-                    WARN "Error connecting to PlugAuth at $auth_url : @{[ $error->{code} ]} @{[ $error->{message} ]}";
+                my ( $message, $code ) = $tx->error;
+                if ($code) {
+                    WARN "Error connecting to PlugAuth at $auth_url : $code $message";
                 } else {
-                    WARN "Error connecting to PlugAuth at $auth_url : @{[ encode_json $error ]}";
+                    WARN "Error connecting to PlugAuth at $auth_url : $message";
                 }
                 $c->render(text => "auth server down", status => 503); # "Service unavailable"
                 return;
@@ -130,9 +127,9 @@ sub authorize {
 
     my $url = Mojo::URL->new( join '/', $self->config_url, "authz/user", $user, $action, $resource );
 
-    my $tx = $c->ua->build_tx(HEAD => $url);
+    my $tx = $c->auth_ua->build_tx(HEAD => $url);
     
-    $c->ua->start($tx, sub {
+    $c->auth_ua->start($tx, sub {
         my($ua, $tx) = @_;
         
         my $code = $tx->res->code;
@@ -167,21 +164,29 @@ Clustericious::Plugin::PlugAuth - Plugin for clustericious to use PlugAuth.
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
 MyApp.conf:
 
- ---
- plug_auth:
-   url: http://plugauthserver:3000
+ {"plug_auth":{"url":"http://plugauthserver:3000"}}
 
 Application:
 
  package MyApp;
  
  use base qw( Clustericious::App );
+ 
+ sub startup {
+   my $self = shift;
+   $self->SUPER::startup(@_);
+   # done by default for all clustericious applications.
+   #$self->plugin('plug_auth');
+ }
+ 
+ package MyApp::Routes;
+ 
  use Clustericious::RouteBuilder;
 
  # unprotected 
@@ -249,8 +254,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
