@@ -6,8 +6,7 @@ use Clustericious::Log;
 use Data::Dumper;
 
 # ABSTRACT: build crud routes easily
-our $VERSION = '1.28_01'; # TRIAL VERSION 
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION 
 
 
 use Sub::Exporter -setup => {
@@ -192,7 +191,7 @@ Clustericious::RouteBuilder::CRUD - build crud routes easily
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -239,8 +238,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
