@@ -2,9 +2,10 @@ package Clustericious::RouteBuilder::Proxy;
 
 use strict;
 use warnings;
+use Clustericious::Log;
 
 # ABSTRACT: build proxy routes easily
-our $VERSION = '1.10_04'; # TRIAL VERSION
+our $VERSION = '1.01'; # VERSION
 
 
 use Sub::Exporter -setup => {
@@ -83,7 +84,7 @@ sub _build_proxy_service {
     my $service2sub;
     for my $service (keys %$name2url) {
         my $dest = $name2url->{$service} or next;
-        #TRACE "Building proxy for $service to $dest";
+        TRACE "Building proxy for $service to $dest";
         my $sub = $class->_build_proxy( "dummy", { to => $dest, strip_prefix => "/$service" } );
         $service2sub->{$service} = $sub;
     }
@@ -118,7 +119,7 @@ Clustericious::RouteBuilder::Proxy - build proxy routes easily
 
 =head1 VERSION
 
-version 1.10_04
+version 1.01
 
 =head1 SYNOPSIS
 
