@@ -3,10 +3,11 @@ package Clustericious::RouteBuilder::Search;
 use strict;
 use warnings;
 use Clustericious::Log;
+use List::MoreUtils qw/uniq/;
+use Data::Dumper;
 
 # ABSTRACT: build routes for searching for objects
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 use Sub::Exporter -setup => {
@@ -50,7 +51,7 @@ sub _build_search {
         }
 
 
-        #TRACE "searching for $items : ".Dumper($p);
+        TRACE "searching for $items : ".Dumper($p);
 
         # maybe restrict, by first calling $manager->normalize_get_objects_args(%$p)
 
@@ -93,7 +94,7 @@ Clustericious::RouteBuilder::Search - build routes for searching for objects
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -148,8 +149,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
