@@ -2,19 +2,19 @@ package Test::Clustericious;
 
 use strict;
 use warnings;
+
+# ABSTRACT: Test Clustericious apps
+our $VERSION = '1.01'; # VERSION
+
+
 use base 'Test::Mojo';
-use JSON::MaybeXS qw( encode_json decode_json );
+
+use JSON::XS;
 use YAML::XS;
 use Carp;
 use List::Util qw(first);
 use Clustericious::Config;
 
-Carp::carp "Test::Clustericious is deprecated and will be removed on or after January 31 2016";
-
-# ABSTRACT: Test Clustericious applications
-our $VERSION = '1.10_04'; # TRIAL VERSION
-
-
 require Test::More;
 
 
@@ -209,11 +209,11 @@ __END__
 
 =head1 NAME
 
-Test::Clustericious - Test Clustericious applications
+Test::Clustericious - Test Clustericious apps
 
 =head1 VERSION
 
-version 1.10_04
+version 1.01
 
 =head1 SYNOPSIS
 
