@@ -3,15 +3,22 @@ package Test::Clustericious::Config;
 use strict;
 use warnings;
 use 5.010001;
-use Test2::Plugin::FauxHomeDir;
-use File::Glob qw( bsd_glob );
+
+BEGIN {
+  unless($INC{'File/HomeDir/Test.pm'})
+  {
+    eval q{ use File::HomeDir::Test };
+    die $@ if $@;
+  }
+}
+
+use File::HomeDir;
 use YAML::XS qw( DumpFile );
 use File::Path qw( mkpath );
 use Clustericious::Config;
 use Mojo::Loader;
-use Clustericious;
-use Test2::API qw( context );
-use base qw( Exporter );
+
+use base qw( Test::Builder::Module Exporter );
 
 our @EXPORT = qw( create_config_ok create_directory_ok home_directory_ok create_config_helper_ok );
 our @EXPORT_OK = @EXPORT;
@@ -21,18 +28,17 @@ my $config_dir;
 
 sub _init
 {
-  $config_dir = bsd_glob('~/etc');
+  $config_dir = File::HomeDir->my_home . "/etc";
   mkdir $config_dir;
 
   $ENV{CLUSTERICIOUS_CONF_DIR} = $config_dir;
-  Clustericious->_testing(1);
+  Clustericious::Config->_testing(1);
 }
 
 BEGIN { _init() }
 
 # ABSTRACT: Test Clustericious::Config
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.01'; # VERSION
 
 
 sub create_config_ok ($;$$)
@@ -45,55 +51,45 @@ sub create_config_ok ($;$$)
   unless(defined $config)
   {
     my $caller = caller;
-    Mojo::Loader::load_class($caller) unless $caller eq 'main';
+    Mojo::Loader::load_class($caller);
     $config = Mojo::Loader::data_section($caller, "etc/$fn");
   }
   
-  my @diag;
-  my $config_filename;
-  
-  my $ctx = context();
+  my $tb = __PACKAGE__->builder;  
   my $ok = 1;
-  if(!defined $config)
+  unless(defined $config)
   {
     $config = "---\n";
-    push @diag, "unable to locate text for $config_name";
+    $tb->diag("unable to locate text for $config_name");
     $ok = 0;
-    $test_name //= "create config for $config_name";
   }
-  else
-  {
-    $config_filename = "$config_dir/$fn";
   
-    eval {
-      if(ref $config)
-      {
-        DumpFile($config_filename, $config);
-      }
-      else
-      {
-        open my $fh, '>', $config_filename;
-        print $fh $config;
-        close $fh;
-      }
-    };
-    if(my $error = $@)
+  my $config_filename = "$config_dir/$fn";
+  
+  eval {
+    if(ref $config)
     {
-      $ok = 0;
-      push @diag, "exception: $error";
+      DumpFile($config_filename, $config);
     }
-  
-    $test_name //= "create config for $config_name at $config_filename";
-  
-    # remove any cached copy if necessary
-    Clustericious->_config_uncache($config_name);
+    else
+    {
+      open my $fh, '>', $config_filename;
+      print $fh $config;
+      close $fh;
+    }
+  };
+  if(my $error = $@)
+  {
+    $ok = 0;
+    $tb->diag("exception: $error");
   }
+  
+  $test_name //= "create config for $config_name at $config_filename";
+  
+  # remove any cached copy if necessary
+  Clustericious::Config->_uncache($config_name);
 
-  $ctx->ok($ok, $test_name);
-  $ctx->diag($_) for @diag;  
-  
-  $ctx->release;
-  
+  $tb->ok($ok, $test_name);
   return $config_filename;
 }
 
@@ -101,29 +97,16 @@ sub create_config_ok ($;$$)
 sub create_directory_ok ($;$)
 {
   my($path, $test_name) = @_;
-
-  my $fullpath;
-  my $ok;
   
-  if(defined $path)
-  {
-    $fullpath = $path;
-    $fullpath =~ s{^/}{};
-    $fullpath = bsd_glob("~/$fullpath");
-    mkpath $fullpath, 0, 0700;
+  my $fullpath = $path;
+  $fullpath =~ s{^/}{};
+  $fullpath = join('/', File::HomeDir->my_home, $fullpath);
+  mkpath $fullpath, 0, 0700;
   
-    $test_name //= "create directory $fullpath";
-    $ok = -d $fullpath;
-  }
-  else
-  {
-    $test_name //= "create directory [undef]";
-    $ok = 0;
-  }
+  $test_name //= "create directory $fullpath";
   
-  my $ctx = context();
-  $ctx->ok($ok, $test_name);
-  $ctx->release;
+  my $tb = __PACKAGE__->builder;
+  $tb->ok(-d $fullpath, $test_name);
   return $fullpath;
 }
 
@@ -132,13 +115,12 @@ sub home_directory_ok (;$)
 {
   my($test_name) = @_;
   
-  my $fullpath = bsd_glob('~');
+  my $fullpath = File::HomeDir->my_home;
   
   $test_name //= "home directory $fullpath";
   
-  my $ctx = context();
-  $ctx->ok(-d $fullpath, $test_name);
-  $ctx->release;
+  my $tb = __PACKAGE__->builder;
+  $tb->ok(-d $fullpath, $test_name);
   return $fullpath;
 }
 
@@ -148,7 +130,6 @@ sub create_config_helper_ok ($$;$)
   my($helper_name, $helper_code, $test_name) = @_;
   
   $test_name //= "create config helper $helper_name";
-  my $ok = 1;
   
   require Clustericious::Config::Helpers;
   do {
@@ -157,10 +138,9 @@ sub create_config_helper_ok ($$;$)
   };
   push @Clustericious::Config::Helpers::EXPORT, $helper_name;
   
-  my $ctx = context();
-  $ctx->ok($ok, $test_name);
-  $ctx->release;
-  return $ok;
+  my $tb = __PACKAGE__->builder;
+  $tb->ok(1, $test_name);
+  return;
 }
 
 1;
@@ -177,7 +157,7 @@ Test::Clustericious::Config - Test Clustericious::Config
 
 =head1 VERSION
 
-version 1.28_01
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -225,20 +205,17 @@ This module provides an interface for testing Clustericious
 configurations, or Clustericious applications which use
 a Clustericious configuration.
 
-It uses L<Test2::Plugin::FauxHomeDir> to isolate your test environment
+It uses L<File::HomeDir::Test> to isolate your test environment
 from any configurations you may have in your C<~/etc>.  Keep
 in mind that this means that C<$HOME> and friends will be in
 a temporary directory and removed after the test runs.  It also
-means that the caveats for L<Test2::Plugin::FauxHomeDir> apply when
-using this module as well (specifically this should be the first module
+means that the caveats for L<File::HomeDir::Test> apply when
+using this module as well (ie. this should be the first module
 that you use in your test after C<use strict> and C<use warnings>).
 
 =head1 FUNCTIONS
 
-=head2 create_config_ok
-
-  create_config_ok $name, $config;
-  create_config_ok $name, $config, $test_name;
+=head2 create_config_ok $name, $config, [$test_name]
 
 Create a Clustericious config with the given C<$name>.
 If C<$config> is a reference then it will create the 
@@ -269,28 +246,19 @@ In addition to being a test that will produce a ok/not ok
 result as output, this function will return the full path
 to the configuration file created.
 
-=head2 create_directory_ok
-
- create_directory_ok $path;
- create_directory_ok $path, $test_name;
+=head2 create_directory_ok $path, [$test_name]
 
 Creates a directory in your test environment home directory.
 This directory will be recursively removed when your test
 terminates.  This function returns the full path of the 
 directory created.
 
-=head2 home_directory_ok
-
- home_directory_ok;
- home_directory_ok $test_name;
+=head2 home_directory_ok [$test_name]
 
 Tests that the temp home directory has been created okay.
 Returns the full path of the home directory.
 
-=head2 create_config_helper_ok
-
- create_config_helper_ok $helper_name, $helper_coderef;
- create_config_helper_ok $helper_name, $helper_coderef, $test_name;
+=head2 create_config_helper_ok $helper_name, $helper_coderef, [ $test_name ]
 
 Install a helper which can be called from within a configuration template.
 Example:
@@ -343,8 +311,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
